@@ -52,7 +52,7 @@ public:
     void slotItemsFetchedForFilter(const Akonadi::Item::List &items);
     void showNotification(const QString &errorMsg, const QString &jobErrorString);
 
-    bool isMatching(const Akonadi::Item &item, const MailCommon::MailFilter *filter);
+    [[nodiscard]] bool isMatching(const Akonadi::Item &item, const MailCommon::MailFilter *filter);
     void beginFiltering(const Akonadi::Item &item) const;
     void endFiltering(const Akonadi::Item &item) const;
     [[nodiscard]] bool atLeastOneFilterAppliesTo(const QString &accountId) const;
@@ -142,7 +142,7 @@ void FilterManager::Private::itemFetchJobForFilterDone(KJob *job)
     }
 
     const QString resourceId = fetchJob->property("resourceId").toString();
-    bool needsFullPayload = q->requiredPart(resourceId) != SearchRule::Envelope;
+    const bool needsFullPayload = q->requiredPart(resourceId) != SearchRule::Envelope;
 
     if (job->property("filterId").isValid()) {
         const QString filterId = job->property("filterId").toString();
@@ -557,7 +557,7 @@ QString FilterManager::createUniqueName(const QString &name) const
                 found = true;
                 ++counter;
                 uniqueName = name;
-                uniqueName += QLatin1String(" (") + QString::number(counter) + QLatin1String(")");
+                uniqueName += QLatin1StringView(" (") + QString::number(counter) + QLatin1StringView(")");
                 break;
             }
         }
