@@ -5,6 +5,8 @@
 */
 
 #include "sendlaterconfiguredialog.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "kmail-version.h"
 #include "sendlaterconfigurewidget.h"
 
@@ -37,7 +39,7 @@ SendLaterConfigureDialog::SendLaterConfigureDialog(QWidget *parent)
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &SendLaterConfigureDialog::reject);
 
-    mWidget->setObjectName(QLatin1StringView("sendlaterwidget"));
+    mWidget->setObjectName("sendlaterwidget"_L1);
     connect(mWidget, &SendLaterWidget::sendNow, this, &SendLaterConfigureDialog::sendNow);
     mainLayout->addWidget(mWidget);
     mainLayout->addWidget(buttonBox);
@@ -50,7 +52,7 @@ SendLaterConfigureDialog::SendLaterConfigureDialog(QWidget *parent)
                                       QStringLiteral(KDEPIM_VERSION),
                                       i18n("Send emails later agent."),
                                       KAboutLicense::GPL_V2,
-                                      i18n("Copyright (C) 2013-%1 Laurent Montel", QStringLiteral("2023")));
+                                      i18n("Copyright (C) 2013-%1 Laurent Montel", QStringLiteral("2024")));
 
     aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
     aboutData.setProductName(QByteArrayLiteral("Akonadi/SendLaterAgent"));
@@ -89,7 +91,7 @@ void SendLaterConfigureDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(800, 600));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myConfigureSendLaterConfigureDialogGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myConfigureSendLaterConfigureDialogGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 
@@ -98,7 +100,7 @@ void SendLaterConfigureDialog::readConfig()
 
 void SendLaterConfigureDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myConfigureSendLaterConfigureDialogGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myConfigureSendLaterConfigureDialogGroupName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
     mWidget->saveTreeWidgetHeader(group);
 }
