@@ -12,6 +12,8 @@
 */
 
 #include "ktnefmain.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "attachpropertydialog.h"
 #include "ktnefview.h"
 #include "messagepropertydialog.h"
@@ -66,7 +68,7 @@ KTNEFMain::KTNEFMain(QWidget *parent)
     mLastDir = mDefaultDir;
 
     // create personal temp extract dir
-    QDir().mkpath(QStandardPaths::writableLocation(QStandardPaths::TempLocation) + QLatin1String("/ktnef/"));
+    QDir().mkpath(QStandardPaths::writableLocation(QStandardPaths::TempLocation) + "/ktnef/"_L1);
 
     resize(430, 350);
 
@@ -228,7 +230,7 @@ void KTNEFMain::viewFile()
         QUrl url = QUrl::fromLocalFile(extractTemp(attach));
         QString mimename(attach->mimeTag());
 
-        if (mimename.isEmpty() || mimename == QLatin1String("application/octet-stream")) {
+        if (mimename.isEmpty() || mimename == "application/octet-stream"_L1) {
             qCDebug(KTNEFAPPS_LOG) << "No mime type found in attachment object, trying to guess...";
             QMimeDatabase db;
             mimename = db.mimeTypeForFile(url.path(), QMimeDatabase::MatchExtension).name();
@@ -247,7 +249,7 @@ void KTNEFMain::viewFile()
 
 QString KTNEFMain::extractTemp(KTNEFAttach *att)
 {
-    QString dir = QStandardPaths::writableLocation(QStandardPaths::TempLocation) + QLatin1String("/ktnef/");
+    QString dir = QStandardPaths::writableLocation(QStandardPaths::TempLocation) + "/ktnef/"_L1;
     mParser->extractFileTo(att->name(), dir);
     QString filename = att->fileName();
     // falling back to internal TNEF attachement name if no filename is given for the attached file
@@ -362,7 +364,7 @@ void KTNEFMain::enableSingleAction(bool on)
 
 void KTNEFMain::cleanup()
 {
-    QDir d(QStandardPaths::writableLocation(QStandardPaths::TempLocation) + QLatin1String("/ktnef/"));
+    QDir d(QStandardPaths::writableLocation(QStandardPaths::TempLocation) + "/ktnef/"_L1);
     d.removeRecursively();
 }
 
@@ -470,8 +472,7 @@ void KTNEFMain::slotShowMessageText()
 
     const QString rtf = mParser->message()->rtfString();
     if (!rtf.isEmpty()) {
-        auto tmpFile =
-            new QTemporaryFile(QStandardPaths::writableLocation(QStandardPaths::TempLocation) + QLatin1String("/ktnef/") + QLatin1String("ktnef_XXXXXX.rtf"));
+        auto tmpFile = new QTemporaryFile(QStandardPaths::writableLocation(QStandardPaths::TempLocation) + "/ktnef/"_L1 + "ktnef_XXXXXX.rtf"_L1);
         tmpFile->setAutoRemove(false);
         tmpFile->open();
         tmpFile->setPermissions(QFile::ReadUser);
@@ -551,7 +552,7 @@ void KTNEFMain::createOpenWithMenu(QMenu *topMenu)
 
         if (offers.count() > 1) { // submenu 'open with'
             menu = new QMenu(i18nc("@title:menu", "&Open With"), topMenu);
-            menu->menuAction()->setObjectName(QLatin1StringView("openWith_submenu")); // for the unittest
+            menu->menuAction()->setObjectName("openWith_submenu"_L1); // for the unittest
             topMenu->addMenu(menu);
         }
         for (const auto &s : offers) {
