@@ -5,6 +5,8 @@
 */
 
 #include "configureaccountpage.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "configagentdelegate.h"
 #include "kmkernel.h"
 #include "newmailnotifierinterface.h"
@@ -14,11 +16,11 @@
 #include <MessageComposer/MessageComposerSettings>
 #include <PimCommon/ConfigureImmutableWidgetUtils>
 using namespace PimCommon::ConfigureImmutableWidgetUtils;
-#include <MailTransport/TransportManagementWidget>
-using MailTransport::TransportManagementWidget;
+#include <MailTransport/TransportManagementWidgetNg>
+using MailTransport::TransportManagementWidgetNg;
 #include <MailCommon/MailUtil>
 
-#include "kmail_debug.h"
+#include "identity/identitypage.h"
 #include <Akonadi/AgentConfigurationDialog>
 #include <Akonadi/AgentManager>
 #include <Akonadi/AgentType>
@@ -28,7 +30,6 @@ using MailTransport::TransportManagementWidget;
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <QComboBox>
-#include <identity/identitypage.h>
 
 #include <QAbstractItemView>
 #include <QFormLayout>
@@ -84,18 +85,26 @@ AccountsPageSendingTab::AccountsPageSendingTab(QWidget *parent)
     // label: zero stretch ### FIXME more
     formLayout->addRow(new QLabel(i18n("Outgoing accounts (add at least one):"), this));
 
-    auto tmw = new TransportManagementWidget(this);
+    auto tmw = new TransportManagementWidgetNg(this);
     tmw->layout()->setContentsMargins({});
     formLayout->addRow(tmw);
 
     // "confirm before send" check box:
     mConfirmSendCheck = new QCheckBox(i18n("&Confirm action"), this);
     formLayout->addRow(i18n("Before sending:"), mConfirmSendCheck);
+#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
     connect(mConfirmSendCheck, &QCheckBox::stateChanged, this, &AccountsPageSendingTab::slotEmitChanged);
+#else
+    connect(mConfirmSendCheck, &QCheckBox::checkStateChanged, this, &AccountsPageSendingTab::slotEmitChanged);
+#endif
 
     mCheckSpellingBeforeSending = new QCheckBox(i18n("Check spelling"), this);
     formLayout->addRow(QString(), mCheckSpellingBeforeSending);
+#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
     connect(mCheckSpellingBeforeSending, &QCheckBox::stateChanged, this, &AccountsPageSendingTab::slotEmitChanged);
+#else
+    connect(mCheckSpellingBeforeSending, &QCheckBox::checkStateChanged, this, &AccountsPageSendingTab::slotEmitChanged);
+#endif
 
     // "send on check" combo:
     mSendOnCheckCombo = new QComboBox(this);
@@ -187,7 +196,11 @@ AccountsPageReceivingTab::AccountsPageReceivingTab(QWidget *parent)
     mAccountsReceiving.mAccountsReceiving->setItemDelegate(configDelegate);
     connect(configDelegate, &ConfigAgentDelegate::optionsClicked, this, &AccountsPageReceivingTab::slotShowMailCheckMenu);
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
     connect(mAccountsReceiving.mVerboseNotificationCheck, &QCheckBox::stateChanged, this, &ConfigModuleTab::slotEmitChanged);
+#else
+    connect(mAccountsReceiving.mVerboseNotificationCheck, &QCheckBox::checkStateChanged, this, &ConfigModuleTab::slotEmitChanged);
+#endif
 
     connect(mAccountsReceiving.mOtherNewMailActionsButton, &QAbstractButton::clicked, this, &AccountsPageReceivingTab::slotEditNotifications);
     connect(mAccountsReceiving.customizeAccountOrder, &QAbstractButton::clicked, this, &AccountsPageReceivingTab::slotCustomizeAccountOrder);
@@ -250,7 +263,7 @@ void AccountsPageReceivingTab::slotShowMailCheckMenu(const QString &ident, const
         IncludeInManualChecks = group.readEntry("IncludeInManualChecks", true);
 
         // Keep sync with kmkernel, don't forget to change there.
-        OfflineOnShutdown = group.readEntry("OfflineOnShutdown", ident.startsWith(QLatin1String("akonadi_pop3_resource")) ? true : false);
+        OfflineOnShutdown = group.readEntry("OfflineOnShutdown", ident.startsWith("akonadi_pop3_resource"_L1) ? true : false);
 
         CheckOnStartup = group.readEntry("CheckOnStartup", false);
         QSharedPointer<RetrievalOptions> opts(new RetrievalOptions(IncludeInManualChecks, OfflineOnShutdown, CheckOnStartup));
