@@ -9,6 +9,7 @@
 // define this to copy all html that is written to the readerwindow to
 // filehtmlwriter.out in the current working directory
 #include "kmreaderwin.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include "dialog/addemailtoexistingcontactdialog.h"
 #include "job/addemailtoexistingcontactjob.h"
@@ -81,7 +82,7 @@ KMReaderWin::KMReaderWin(QWidget *aParent, QWidget *mainWindow, KActionCollectio
 {
     createActions();
     auto vlay = new QVBoxLayout(this);
-    vlay->setContentsMargins(0, 0, 0, 0);
+    vlay->setContentsMargins({});
     mViewer = new Viewer(this, mainWindow, mActionCollection);
     mViewer->setIdentityManager(kmkernel->identityManager());
     connect(mViewer, qOverload<const Akonadi::Item &, const QUrl &>(&Viewer::urlClicked), this, &KMReaderWin::slotUrlClicked);
@@ -292,7 +293,7 @@ QString KMReaderWin::newFeaturesMD5()
     }
     QCryptographicHash md5(QCryptographicHash::Md5);
     md5.addData(str);
-    return QLatin1String(md5.result().toBase64());
+    return QLatin1StringView(md5.result().toBase64());
 }
 
 void KMReaderWin::displaySplashPage(const QString &templateName, const QVariantHash &_data)
@@ -775,8 +776,12 @@ bool KMReaderWin::printSelectedText(bool preview)
     composer->textPart()->setWrappedPlainText(str);
     auto messagePtr = messageItem().payload<KMime::Message::Ptr>();
     composer->infoPart()->setFrom(messagePtr->from()->asUnicodeString());
-    composer->infoPart()->setTo(QStringList() << messagePtr->to()->asUnicodeString());
-    composer->infoPart()->setCc(QStringList() << messagePtr->cc()->asUnicodeString());
+    if (auto to = messagePtr->to(false)) {
+        composer->infoPart()->setTo(QStringList() << to->asUnicodeString());
+    }
+    if (auto cc = messagePtr->cc(false)) {
+        composer->infoPart()->setCc(QStringList() << cc->asUnicodeString());
+    }
     if (auto subject = messagePtr->subject(false)) {
         composer->infoPart()->setSubject(subject->asUnicodeString());
     }
@@ -846,12 +851,12 @@ void KMReaderWin::updateHtmlActions()
     } else {
         const QStringList customs = mSearchedAddress.customs();
         for (const QString &custom : customs) {
-            if (custom.contains(QLatin1String("MailPreferedFormatting"))) {
+            if (custom.contains("MailPreferedFormatting"_L1)) {
                 const QString value = mSearchedAddress.custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("MailPreferedFormatting"));
-                mViewAsHtml->setChecked(value == QLatin1String("HTML"));
-            } else if (custom.contains(QLatin1String("MailAllowToRemoteContent"))) {
+                mViewAsHtml->setChecked(value == "HTML"_L1);
+            } else if (custom.contains("MailAllowToRemoteContent"_L1)) {
                 const QString value = mSearchedAddress.custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("MailAllowToRemoteContent"));
-                mLoadExternalReference->setChecked((value == QLatin1String("TRUE")));
+                mLoadExternalReference->setChecked((value == "TRUE"_L1));
             }
         }
     }
