@@ -7,6 +7,8 @@
 */
 
 #include "kmail_plugin.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "kmailinterface.h"
 #include "summarywidget.h"
 
@@ -99,7 +101,7 @@ void KMailPlugin::processDropEvent(QDropEvent *de)
         for (const auto &s : std::as_const(list)) {
             to.append(s.fullEmail());
         }
-        openComposer(to.join(QLatin1String(", ")));
+        openComposer(to.join(", "_L1));
     }
 
     qCWarning(KMAILPLUGIN_LOG) << QStringLiteral("Cannot handle drop events of type '%1'.").arg(de->mimeData()->formats().join(QLatin1Char(';')));
@@ -108,12 +110,12 @@ void KMailPlugin::processDropEvent(QDropEvent *de)
 void KMailPlugin::openComposer(const QUrl &attach)
 {
     (void)part(); // ensure part is loaded
-    Q_ASSERT(m_instance);
-    if (m_instance) {
+    Q_ASSERT(mInstance);
+    if (mInstance) {
         if (attach.isValid()) {
-            m_instance->newMessage(QString(), QString(), QString(), false, true, QString(), attach.isLocalFile() ? attach.toLocalFile() : attach.path());
+            mInstance->newMessage(QString(), QString(), QString(), false, true, QString(), attach.isLocalFile() ? attach.toLocalFile() : attach.path());
         } else {
-            m_instance->newMessage(QString(), QString(), QString(), false, true, QString(), QString());
+            mInstance->newMessage(QString(), QString(), QString(), false, true, QString(), QString());
         }
     }
 }
@@ -121,9 +123,9 @@ void KMailPlugin::openComposer(const QUrl &attach)
 void KMailPlugin::openComposer(const QString &to)
 {
     (void)part(); // ensure part is loaded
-    Q_ASSERT(m_instance);
-    if (m_instance) {
-        m_instance->newMessage(to, QString(), QString(), false, true, QString(), QString());
+    Q_ASSERT(mInstance);
+    if (mInstance) {
+        mInstance->newMessage(to, QString(), QString(), false, true, QString(), QString());
     }
 }
 
@@ -143,8 +145,8 @@ void KMailPlugin::slotSyncFolders()
 
 KMailPlugin::~KMailPlugin()
 {
-    delete m_instance;
-    m_instance = nullptr;
+    delete mInstance;
+    mInstance = nullptr;
 }
 
 KParts::Part *KMailPlugin::createPart()
@@ -154,7 +156,7 @@ KParts::Part *KMailPlugin::createPart()
         return nullptr;
     }
 
-    m_instance = new OrgKdeKmailKmailInterface(QStringLiteral("org.kde.kmail"), QStringLiteral("/KMail"), QDBusConnection::sessionBus());
+    mInstance = new OrgKdeKmailKmailInterface(QStringLiteral("org.kde.kmail"), QStringLiteral("/KMail"), QDBusConnection::sessionBus());
 
     return part;
 }
