@@ -7,6 +7,8 @@
  */
 
 #include "summaryview_plugin.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "kmail-version.h"
 #include "kmailinterface.h"
 #include "summaryview_part.h"
@@ -25,8 +27,8 @@ EXPORT_KONTACT_PLUGIN_WITH_JSON(SummaryView, "summaryplugin.json")
 
 SummaryView::SummaryView(KontactInterface::Core *core, const KPluginMetaData &data, const QVariantList &)
     : KontactInterface::Plugin(core, core, data, nullptr)
+    , mSyncAction(new KSelectAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18n("Sync All"), this))
 {
-    mSyncAction = new KSelectAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18n("Sync All"), this);
     actionCollection()->addAction(QStringLiteral("kontact_summary_sync"), mSyncAction);
     connect(mSyncAction, &KSelectAction::actionTriggered, this, &SummaryView::syncAccount);
     connect(mSyncAction->menu(), &QMenu::aboutToShow, this, &SummaryView::fillSyncActionSubEntries);
@@ -90,7 +92,7 @@ void SummaryView::doSync()
 KParts::Part *SummaryView::createPart()
 {
     mPart = new SummaryViewPart(core(), aboutData(), this);
-    mPart->setObjectName(QLatin1StringView("summaryPart"));
+    mPart->setObjectName("summaryPart"_L1);
     return mPart;
 }
 
@@ -101,7 +103,7 @@ const KAboutData SummaryView::aboutData()
                                       QStringLiteral(KDEPIM_VERSION),
                                       i18n("Kontact Summary View"),
                                       KAboutLicense::LGPL,
-                                      i18n("(c) 2003-2021 The Kontact developers"));
+                                      i18n("(c) 2003-2024 The Kontact developers"));
 
     aboutData.addAuthor(i18n("Sven Lueppken"), QString(), QStringLiteral("sven@kde.org"));
     aboutData.addAuthor(i18n("Cornelius Schumacher"), QString(), QStringLiteral("schumacher@kde.org"));
