@@ -5,6 +5,7 @@
 */
 
 #include "tagselectdialog.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include "kmail_debug.h"
 
@@ -59,9 +60,9 @@ TagSelectDialog::TagSelectDialog(QWidget *parent, int numberOfSelectedMessages,
     auto vbox = new QVBoxLayout;
     mainWidget->setLayout(vbox);
     vbox->setContentsMargins({});
-    mListTag->setObjectName(QLatin1StringView("listtag"));
+    mListTag->setObjectName("listtag"_L1);
     auto listWidgetSearchLine = new KListWidgetSearchLine(this, mListTag);
-    listWidgetSearchLine->setObjectName(QLatin1StringView("searchline"));
+    listWidgetSearchLine->setObjectName("searchline"_L1);
 
     listWidgetSearchLine->setPlaceholderText(i18n("Search tag..."));
     listWidgetSearchLine->setClearButtonEnabled(true);
@@ -84,14 +85,14 @@ void TagSelectDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(500, 300));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myTagSelectDialogGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myTagSelectDialogGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void TagSelectDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myTagSelectDialogGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myTagSelectDialogGroupName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
 }
 
